@@ -2,6 +2,7 @@
 
 import os
 import sys
+import django
 
 from django.conf import settings
 
@@ -23,22 +24,32 @@ if not settings.configured:
                 "PORT": "",
             }
         },
+        MIDDLEWARE_CLASSES = ()
     )
 
     settings.configure(**settings_dict)
+    if django.VERSION >= (1, 7):
+        django.setup()
 
 
 def runtests(*test_args):
     if not test_args:
-        test_args = ['tests']
+        test_args = ['django_pandas']
 
     parent = os.path.dirname(os.path.abspath(__file__))
     sys.path.insert(0, parent)
 
-    from django.test.simple import DjangoTestSuiteRunner
-    failures = DjangoTestSuiteRunner(
-        verbosity=1, interactive=True, failfast=False).run_tests(test_args)
-    sys.exit(failures)
+    if django.VERSION < (1, 8):
+        from django.test.simple import DjangoTestSuiteRunner
+        failures = DjangoTestSuiteRunner(
+            verbosity=1, interactive=True, failfast=False).run_tests(['tests'])
+        sys.exit(failures)
+
+    else:
+        from django.test.runner import DiscoverRunner
+        failures = DiscoverRunner(
+            verbosity=1, interactive=True, failfast=False).run_tests(test_args)
+        sys.exit(failures)
 
 
 if __name__ == '__main__':
